@@ -13,4 +13,18 @@ ci_binom = function(centx,n,conf_level=.95){
   ucl <- (p1 + p2)/p3
   res = c(lcl,ucl)
   return(res)
+}
+
+
+
+smean.sdl = function (x, mult = 1, na.rm = TRUE) {
+  if (na.rm) 
+    x <- x[!is.na(x)]
+  n <- length(x)
+  if (n == 0) 
+    return(c(Mean = NA, Lower = NA, Upper = NA))
+  xbar <- sum(x)/n
+  sd <- sqrt(sum((x - xbar)^2)/(n - 1))
+  c(Mean = xbar, Lower = xbar - mult * sd, Upper = xbar + 
+      mult * sd)
 }
\ No newline at end of file
