@@ -11,18 +11,18 @@ Superpower_options(verbose = FALSE,
                    plot = FALSE)
 nsims = 250
 
-## ---- fig.width=7, fig.height=4-----------------------------------------------
+## ----fig.width=7, fig.height=4------------------------------------------------
 design <- "3b"
 n <- 50
 mu <- c(24, 26.2, 26.6)
 sd <- 6.4
-labelnames <- c("condition", "control", "cat", "dog") #
+label_list = list("condition" = c("control", "cat", "dog"))
 
 design_result <- ANOVA_design(design = design,
                    n = n, 
                    mu = mu, 
                    sd = sd, 
-                   labelnames = labelnames,
+                   label_list = label_list,
                    plot = TRUE)
 
 ## -----------------------------------------------------------------------------
@@ -49,18 +49,18 @@ pwr.t.test(d = 0.4/6.4,
 ## ----eval=FALSE---------------------------------------------------------------
 #  plot_power(design_result, min_n = 10, max_n = 250)
 
-## ---- fig.width=7, fig.height=4-----------------------------------------------
+## ----fig.width=7, fig.height=4------------------------------------------------
 design <- "3b"
 n <- 134
 mu <- c(24, 26.2, 26.6)
 sd <- 6.4
-labelnames <- c("condition", "control", "cat", "dog") #
+label_list = list("condition" = c("control", "cat", "dog"))
 
 design_result <- ANOVA_design(design = design,
                    n = n, 
                    mu = mu, 
                    sd = sd, 
-                   labelnames = labelnames,
+                   label_list = label_list,
                    plot = FALSE) #do not print the plot (same as above)
 
 ANOVA_exact2(design_result,
@@ -71,7 +71,7 @@ design_result <- ANOVA_design(design = design,
                    n = n, 
                    mu = mu, 
                    sd = sd, 
-                   labelnames = labelnames,
+                   label_list = label_list,
                    plot = FALSE) #do not print the plot (same as above)
 
 ANOVA_exact2(design_result,
@@ -82,26 +82,26 @@ design_result <- ANOVA_design(design = design,
                    n = n, 
                    mu = mu, 
                    sd = sd, 
-                   labelnames = labelnames,
+                   label_list = label_list,
                    plot = FALSE) #do not print the plot (same as above)
 
 ANOVA_exact2(design_result,
              emm = TRUE)
 
 
-## ---- out.width = "600px", echo=FALSE-----------------------------------------
+## ----out.width = "600px", echo=FALSE------------------------------------------
 knitr::include_graphics("screenshots/gpower_9.png")
 
-## ---- out.width = "600px", echo=FALSE-----------------------------------------
+## ----out.width = "600px", echo=FALSE------------------------------------------
 knitr::include_graphics("screenshots/gpower_1.png")
 
-## ---- out.width = "600px", echo=FALSE-----------------------------------------
+## ----out.width = "600px", echo=FALSE------------------------------------------
 knitr::include_graphics("screenshots/gpower_11.png")
 
-## ---- out.width = "600px", echo=FALSE-----------------------------------------
+## ----out.width = "600px", echo=FALSE------------------------------------------
 knitr::include_graphics("screenshots/gpower_10.png")
 
-## ---- fig.width=7, fig.height=4-----------------------------------------------
+## ----fig.width=7, fig.height=4------------------------------------------------
 K <- 2
 n <- 34
 sd <- 1
@@ -113,20 +113,20 @@ ES <- f2/(f2+1)
 ES
 mu <- mu_from_ES(K = K, ES = ES)
 design = paste(K,"w",sep="")
-labelnames <- c("speed", "fast", "slow")
+label_list <- list("speed" =c("fast", "slow"))
 
 design_result <- ANOVA_design(design = design,
                               n = n, 
                               mu = mu, 
                               sd = sd, 
                               r = r, 
-                              labelnames = labelnames,
+                              label_list = label_list,
                               plot = TRUE)
 
 ANOVA_exact2(design_result,
             emm = TRUE)
 
-## ---- fig.width=7, fig.height=4-----------------------------------------------
+## ----fig.width=7, fig.height=4------------------------------------------------
 K <- 2
 n <- 34
 sd <- 1
@@ -138,14 +138,14 @@ ES <- f2/(f2+1)
 ES
 mu <- mu_from_ES(K = K, ES = ES)
 design = paste(K,"w",sep="")
-labelnames <- c("speed", "fast", "slow")
+label_list <- list("speed" = c("fast", "slow"))
 
 design_result <- ANOVA_design(design = design,
                               n = n, 
                               mu = mu, 
                               sd = sd, 
                               r = r, 
-                              labelnames = labelnames,
+                              label_list = label_list,
                               plot = TRUE)
 
 ANOVA_exact2(design_result,
@@ -163,7 +163,7 @@ r <- 0.7
 (4.3-4.2)/0.9/sqrt(2*(1-r))
 
 
-## ---- fig.width=7, fig.height=4-----------------------------------------------
+## ----fig.width=7, fig.height=4------------------------------------------------
 K <- 3
 n <- 20
 sd <- 1
@@ -176,14 +176,14 @@ ES
 mu <- mu_from_ES(K = K, ES = ES)
 sqrt(sum((mu-mean(mu))^2)/length(mu))/sd #Cohen, 1988, formula 8.2.1 and 8.2.2
 design = paste(K,"w",sep="")
-labelnames <- c("speed", "fast", "medium", "slow")
+label_list <- list("speed" = c("fast", "medium", "slow"))
 
 design_result <- ANOVA_design(design = design,
                               n = n, 
                               mu = mu, 
                               sd = sd, 
                               r = r, 
-                              labelnames = labelnames,
+                              label_list = label_list,
                               plot = TRUE)
 power_result = ANOVA_power(design_result,
                            nsims = 250)
@@ -193,16 +193,16 @@ confint(power_result,
         level = .98)
 
 
-## ---- out.width = "600px", echo=FALSE-----------------------------------------
+## ----out.width = "600px", echo=FALSE------------------------------------------
 knitr::include_graphics("screenshots/gpower_12.png")
 
-## ---- out.width = "600px", echo=FALSE-----------------------------------------
+## ----out.width = "600px", echo=FALSE------------------------------------------
 knitr::include_graphics("screenshots/gpower_14.png")
 
-## ---- out.width = "600px", echo=FALSE-----------------------------------------
+## ----out.width = "600px", echo=FALSE------------------------------------------
 knitr::include_graphics("screenshots/gpower_5.png")
 
-## ---- fig.width=7, fig.height=4-----------------------------------------------
+## ----fig.width=7, fig.height=4------------------------------------------------
 mu <- c(-0.25, 0.25, 0.25, -0.25)
 n <- 23
 sd <- 1
@@ -219,10 +219,10 @@ ANOVA_exact2(design_result,
              emm = TRUE)
 
 
-## ---- out.width = "600px", echo=FALSE-----------------------------------------
+## ----out.width = "600px", echo=FALSE------------------------------------------
 knitr::include_graphics("screenshots/gpower_6.png")
 
-## ---- fig.width=7, fig.height=4-----------------------------------------------
+## ----fig.width=7, fig.height=4------------------------------------------------
 mu <- c(-0.25, 0.25, 0.25, -0.25)
 n <- 23
 sd <- 1
@@ -245,8 +245,8 @@ design_result_cross_80 <- ANOVA_design(design = "2b*2b",
                                        n = 80, 
                                        mu = c(1, 0, 0, 1), 
                                        sd = 2, 
-                                       labelnames = c("condition", "cheerful", "sad", 
-                                                      "voice", "human", "robot"))
+                                       label_list = list("condition" = c("cheerful","sad"), 
+                                                      "voice" = c("human", "robot")))
 
 plot(design_result_cross_80)
 # 
@@ -254,7 +254,12 @@ power_result_cross_80 <- ANOVA_exact(design_result_cross_80, alpha_level = 0.05,
 
 
 # To save time compiling this vignette, we ran these simulations once, and stored them
-design_result_cross_40 <- ANOVA_design(design = "2b*2b", n = 40, mu = c(1, 0, 0, 1), sd = 2, labelnames = c("condition", "cheerful", "sad", "voice", "human", "robot"), plot = FALSE)
+design_result_cross_40 <- ANOVA_design(design = "2b*2b",
+                                       n = 40, 
+                                       mu = c(1, 0, 0, 1), 
+                                       sd = 2, 
+                                       label_list = list("condition" = c("cheerful", "sad"), 
+                                                                                                            "voice" = c("human", "robot")), plot = FALSE)
 # 
 power_result_cross_40 <- ANOVA_exact(design_result_cross_40, alpha_level = 0.05, verbose = FALSE)
 
@@ -270,8 +275,8 @@ design_result_ordinal <- ANOVA_design(design = "2b*2b",
                                       n = 160, 
                                       mu = c(1, 0, 0, 0), 
                                       sd = 2, 
-                                      labelnames = c("condition", "cheerful", "sad",
-                                                     "voice", "human", "robot"))
+                                      label_list = list("condition" = c("cheerful", "sad"),
+                                                     "voice" = c("human", "robot")))
 # 
 power_result_ordinal <- ANOVA_power(design_result_ordinal, 
                                     alpha_level = 0.05, 
@@ -299,8 +304,8 @@ design_result <-ANOVA_design(design = "2b*2b",
                              n = 40,
                              mu = c(2, 0, 0, 0),
                              sd = 2,
-                             labelnames = c("condition", "cheerful", "sad",
-                                            "voice", "human", "robot"))
+                             label_list = list("condition" = c("cheerful", "sad"),
+                                            "voice" = c( "human", "robot")))
 #Analytic solution
 power_twoway_between(design_result)$power_A
 power_twoway_between(design_result)$power_B
@@ -312,28 +317,30 @@ design_result <- ANOVA_design(design = "2b*2b*2b",
                               n = 20, 
                               mu = c(4, 0, 0, 0, 0, 0, 0, 0), 
                               sd = 2,
-                              labelnames = c("condition", "cheerful", "sad", 
-                                             "voice", "human", "robot", 
-                                             "factor_c", "c1", "c2"))
+                              label_list = list(
+                                "condition" = c("cheerful", "sad"),
+                                "voice" = c("human", "robot"),
+                                "factorC" = c("c1", "c2")
+                              ))
 power_threeway_between(design_result)$power_ABC
 power_threeway_between(design_result)$Cohen_f_ABC
 
 
-## ---- fig.width=7, fig.height=4-----------------------------------------------
+## ----fig.width=7, fig.height=4------------------------------------------------
 design <- "3b*3b"
 n <- 20
 mu <- c(20, 20, 20, 20, 20, 20, 20, 20, 25) 
 # Enter means in the order that matches the labels below.
 sd <- 5
-labelnames <- c("Factor_A", "a1", "a2", "a3", 
-                "Factor_B", "b1", "b2", "b3") #
+label_list <- list("FactorA" = c("a1", "a2", "a3"), 
+                "FactorB" = c("b1", "b2", "b3")) #
 # the label names should be in the order of the means specified above.
 
 design_result <- ANOVA_design(design = design,
                    n = n, 
                    mu = mu, 
                    sd = sd, 
-                   labelnames = labelnames)
+                   label_list = label_list)
 plot(design_result)
 
 res = ANOVA_exact2(design_result, 
@@ -351,14 +358,14 @@ power_res$power_B
 power_res$power_AB
 
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  # Not Run
 #  plot_power(design_result, min_n = 20, max_n = 100)
 
-## ---- out.width = "600px", echo=FALSE-----------------------------------------
+## ----out.width = "600px", echo=FALSE------------------------------------------
 knitr::include_graphics("screenshots/PS2000.gif")
 
-## ---- fig.width=7, fig.height=4-----------------------------------------------
+## ----fig.width=7, fig.height=4------------------------------------------------
 mu = c(2,1,4,2) 
 n <- 20
 sd <- 5
@@ -369,13 +376,14 @@ r <- c(
   )
 
 design = "2w*2w"
-labelnames = c("A", "a1", "a2", "B", "b1", "b2")
+label_list = list("A" =c( "a1", "a2"),
+               "B" = c("b1", "b2"))
 design_result <- ANOVA_design(design = design,
                               n = n, 
                               mu = mu, 
                               sd = sd, 
                               r = r, 
-                              labelnames = labelnames,
+                              label_list = label_list,
                               plot = TRUE)
 
 power_result_vig_4 = ANOVA_power(design_result,
